//  gmodconfig - a Gnome based kernel module configuration tool
//  http://gmodconfig.sourceforge.net/
//  Copyright (C) 2003 Cyril Bortolato
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//  testxsareader.cpp: unit test program for the XSA reader
//--------------------------------------------------------------------------//

#include <iostream>
#include <fstream>
#include "xsareader.h"
#include "xsatypes.h"

using namespace gmodcfg;

static void
check( const string& str, const string& expStr )
{
    if ( str != expStr )
    {
        std::cout << "ERROR: got:\n" << str << "\nexpected:\n" << expStr
                  << std::endl;
        exit(1);
    }
}

int main()
{
    XsaReader reader;
    std::ifstream ifs( "xsatest1.xml" );
    XsaData* xsa = reader.Read( ifs );

    check( xsa->GetVendorName(), "borto" );
    check( xsa->GetVendorEmail(), "borto@NOSPAM.users.sf.net" );
    check( xsa->GetVendorUrl(), "http://gmodconfig.sf.net/" );
    if ( xsa->GetNumProducts() != 2 )
        return 1;

    XsaData::ProductVector::const_iterator it = xsa->BeginProducts();
    const XsaData::Product* p1 = *it;
    check( p1->Id, "pipo-stable" );
    check( p1->Name, "pipo stable" );
    check( p1->Version, "1.0" );
    check( p1->LastRelease, "20030228" );
    check( p1->InfoUrl, "http://gmodconfig.sf.net/pipo/" );
    check( p1->Changes, "\nThis is a stable version of the pipo driver.\n" );

    ++it;
    const XsaData::Product* p2 = *it;
    check( p2->Id, "pipo-exp" );
    check( p2->Name, "pipo experimental" );
    check( p2->Version, "1.42" );
    check( p2->LastRelease, "20030301" );
    check( p2->InfoUrl, "http://gmodconfig.sf.net/pipo/" );
    check( p2->Changes, "\nThis pipo driver has experimental features\n" );

    return 0;
}

